@@ -190,25 +190,42 @@ class AgentTemplateBuilder:
         # Include tools field only if agent is clearly restricted (missing core tools or very few tools)
         include_tools_field = not has_core_tools or len(agent_tools) < 6
 
-        # Build YAML frontmatter using Claude Code's working format + our custom fields
+        # Build YAML frontmatter using Claude Code's minimal format
+        # ONLY include fields that Claude Code recognizes
+        #
+        # CLAUDE CODE COMPATIBLE FORMAT:
+        # - name: kebab-case agent name (required)
+        # - description: when/why to use this agent (required)
+        # - version: agent version for update tracking (recommended)
+        # - tools: comma-separated tool list (optional, only if restricting)
+        # - color, author, tags: metadata fields (optional)
         frontmatter_lines = [
             "---",
             f"name: {claude_code_name}",
             f"description: {description}",
+            f'version: "{agent_version}"',
         ]
 
+        # Add optional metadata if available
+        if metadata.get("color"):
+            frontmatter_lines.append(f"color: {metadata['color']}")
+        if metadata.get("author"):
+            frontmatter_lines.append(f"author: {metadata['author']}")
+        if metadata.get("tags"):
+            frontmatter_lines.append("tags:")
+            for tag in metadata["tags"][:10]:  # Limit to 10 tags
+                frontmatter_lines.append(f"  - {tag}")
+        if metadata.get("priority"):
+            frontmatter_lines.append(f"priority: {metadata['priority']}")
+        if metadata.get("category"):
+            frontmatter_lines.append(f"category: {metadata['category']}")
+
         # Only include tools if restricting to subset
         if include_tools_field:
             frontmatter_lines.append(f"tools: {tools_str}")
 
         frontmatter_lines.extend(
             [
-                f"model: {model_type}",  # Use explicit model type instead of inherit
-                f"color: {color}",
-                f"version: {agent_version}",
-                f"type: {agent_type}",
-                f"source: {source_info}",  # Track which source provided this agent
-                "author: claude-mpm",  # Mark as system-managed agent
                 "---",
                 "",
             ]
